Error

Enum Error 

pub enum Error {
Show 21 variants ThresholdEncryptionError(Error), DealerNotInValidatorSet(EthereumAddress), UnknownDealer(EthereumAddress), DuplicateDealer(EthereumAddress), InvalidPvssTranscript(EthereumAddress), InsufficientValidators(u32, u32), InvalidTranscriptAggregate, ValidatorPublicKeyMismatch, BincodeError(Error), ArkSerializeError(SerializationError), InvalidByteLength(usize, usize), InvalidVariant(String), InvalidDkgParameters(u32, u32), InvalidShareIndex(u32), InvalidShareUpdate, InvalidDkgParametersForPrecomputedVariant(u32, u32), DuplicatedShareIndex(u32), NoTranscriptsToAggregate, InvalidAggregateVerificationParameters(u32, u32), TooManyTranscripts(u32, u32), DuplicateTranscript(EthereumAddress),
}

Variants



ThresholdEncryptionError(Error)



DealerNotInValidatorSet(EthereumAddress)

DKG validator set must contain the validator with the given address



UnknownDealer(EthereumAddress)

DKG received an unknown dealer. Dealer must be the part of the DKG validator set.



DuplicateDealer(EthereumAddress)

DKG received a PVSS transcript from a dealer that has already been dealt.



InvalidPvssTranscript(EthereumAddress)

DKG received an invalid transcript for which optimistic verification failed



InsufficientValidators(u32, u32)

Not enough validators to perform the DKG for a given number of shares



InvalidTranscriptAggregate

Transcript aggregate doesn’t match the received PVSS instances



ValidatorPublicKeyMismatch

The validator public key doesn’t match the one in the DKG



BincodeError(Error)



ArkSerializeError(SerializationError)



InvalidByteLength(usize, usize)

Invalid byte length



InvalidVariant(String)

Invalid variant



InvalidDkgParameters(u32, u32)

DKG parameters validation failed



InvalidShareIndex(u32)

Failed to access a share for a given share index



InvalidShareUpdate

Failed to verify a share update



InvalidDkgParametersForPrecomputedVariant(u32, u32)

Failed to produce a precomputed variant decryption share



DuplicatedShareIndex(u32)

DKG may not contain duplicated share indices



NoTranscriptsToAggregate

Creating a transcript aggregate requires at least one transcript



InvalidAggregateVerificationParameters(u32, u32)

The number of messages may not be greater than the number of validators



TooManyTranscripts(u32, u32)

Too many transcripts received by the DKG



DuplicateTranscript(EthereumAddress)

Received a duplicated transcript from a validator